@@ -1,8 +1,9 @@
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 from . import wrappers, utils
 from pyrallis.help_formatter import SimpleHelpFormatter
-from pyrallis.argparsing import ArgumentParser, ParsingError, wrap
+from pyrallis.argparsing import ArgumentParser, wrap
 from .parsers.encoding import encode, dump
 from .parsers.decoding import decode, load
-from .fields import field
\ No newline at end of file
+from .fields import field
+from .utils import ParsingError
\ No newline at end of file
